"""
Type annotations for kendra service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/type_defs.html)

Usage::

    ```python
    from mypy_boto3_kendra.type_defs import AccessControlListConfigurationTypeDef

    data: AccessControlListConfigurationTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import IO, Any, Dict, List, Union

from mypy_boto3_kendra.literals import (
    ConfluenceAttachmentFieldName,
    ConfluenceBlogFieldName,
    ConfluencePageFieldName,
    ConfluenceSpaceFieldName,
    ConfluenceVersion,
    ContentType,
    DatabaseEngineType,
    DataSourceStatus,
    DataSourceSyncJobStatus,
    DataSourceType,
    DocumentAttributeValueType,
    ErrorCode,
    FaqFileFormat,
    FaqStatus,
    HighlightType,
    IndexEdition,
    IndexStatus,
    KeyLocation,
    Order,
    PrincipalType,
    QueryIdentifiersEnclosingOption,
    QueryResultType,
    ReadAccessType,
    RelevanceType,
    SalesforceChatterFeedIncludeFilterType,
    SalesforceKnowledgeArticleState,
    SalesforceStandardObjectName,
    ScoreConfidence,
    ServiceNowAuthenticationType,
    ServiceNowBuildVersionType,
    SortOrder,
    ThesaurusStatus,
    UserContextPolicy,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AccessControlListConfigurationTypeDef",
    "AclConfigurationTypeDef",
    "AdditionalResultAttributeTypeDef",
    "AdditionalResultAttributeValueTypeDef",
    "AttributeFilterTypeDef",
    "BatchDeleteDocumentResponseFailedDocumentTypeDef",
    "BatchDeleteDocumentResponseTypeDef",
    "BatchPutDocumentResponseFailedDocumentTypeDef",
    "BatchPutDocumentResponseTypeDef",
    "CapacityUnitsConfigurationTypeDef",
    "ClickFeedbackTypeDef",
    "ColumnConfigurationTypeDef",
    "ConfluenceAttachmentConfigurationTypeDef",
    "ConfluenceAttachmentToIndexFieldMappingTypeDef",
    "ConfluenceBlogConfigurationTypeDef",
    "ConfluenceBlogToIndexFieldMappingTypeDef",
    "ConfluenceConfigurationTypeDef",
    "ConfluencePageConfigurationTypeDef",
    "ConfluencePageToIndexFieldMappingTypeDef",
    "ConfluenceSpaceConfigurationTypeDef",
    "ConfluenceSpaceToIndexFieldMappingTypeDef",
    "ConnectionConfigurationTypeDef",
    "CreateDataSourceResponseTypeDef",
    "CreateFaqResponseTypeDef",
    "CreateIndexResponseTypeDef",
    "CreateThesaurusResponseTypeDef",
    "DataSourceConfigurationTypeDef",
    "DataSourceSummaryTypeDef",
    "DataSourceSyncJobMetricTargetTypeDef",
    "DataSourceSyncJobMetricsTypeDef",
    "DataSourceSyncJobTypeDef",
    "DataSourceToIndexFieldMappingTypeDef",
    "DataSourceVpcConfigurationTypeDef",
    "DatabaseConfigurationTypeDef",
    "DescribeDataSourceResponseTypeDef",
    "DescribeFaqResponseTypeDef",
    "DescribeIndexResponseTypeDef",
    "DescribeThesaurusResponseTypeDef",
    "DocumentAttributeTypeDef",
    "DocumentAttributeValueCountPairTypeDef",
    "DocumentAttributeValueTypeDef",
    "DocumentMetadataConfigurationTypeDef",
    "DocumentRelevanceConfigurationTypeDef",
    "DocumentTypeDef",
    "DocumentsMetadataConfigurationTypeDef",
    "FacetResultTypeDef",
    "FacetTypeDef",
    "FaqStatisticsTypeDef",
    "FaqSummaryTypeDef",
    "GoogleDriveConfigurationTypeDef",
    "HighlightTypeDef",
    "IndexConfigurationSummaryTypeDef",
    "IndexStatisticsTypeDef",
    "JsonTokenTypeConfigurationTypeDef",
    "JwtTokenTypeConfigurationTypeDef",
    "ListDataSourceSyncJobsResponseTypeDef",
    "ListDataSourcesResponseTypeDef",
    "ListFaqsResponseTypeDef",
    "ListIndicesResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ListThesauriResponseTypeDef",
    "OneDriveConfigurationTypeDef",
    "OneDriveUsersTypeDef",
    "PrincipalTypeDef",
    "QueryResultItemTypeDef",
    "QueryResultTypeDef",
    "RelevanceFeedbackTypeDef",
    "RelevanceTypeDef",
    "S3DataSourceConfigurationTypeDef",
    "S3PathTypeDef",
    "SalesforceChatterFeedConfigurationTypeDef",
    "SalesforceConfigurationTypeDef",
    "SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef",
    "SalesforceKnowledgeArticleConfigurationTypeDef",
    "SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef",
    "SalesforceStandardObjectAttachmentConfigurationTypeDef",
    "SalesforceStandardObjectConfigurationTypeDef",
    "ScoreAttributesTypeDef",
    "SearchTypeDef",
    "ServerSideEncryptionConfigurationTypeDef",
    "ServiceNowConfigurationTypeDef",
    "ServiceNowKnowledgeArticleConfigurationTypeDef",
    "ServiceNowServiceCatalogConfigurationTypeDef",
    "SharePointConfigurationTypeDef",
    "SortingConfigurationTypeDef",
    "SqlConfigurationTypeDef",
    "StartDataSourceSyncJobResponseTypeDef",
    "TagTypeDef",
    "TextDocumentStatisticsTypeDef",
    "TextWithHighlightsTypeDef",
    "ThesaurusSummaryTypeDef",
    "TimeRangeTypeDef",
    "UserContextTypeDef",
    "UserTokenConfigurationTypeDef",
)


class AccessControlListConfigurationTypeDef(TypedDict, total=False):
    KeyPath: str


class AclConfigurationTypeDef(TypedDict):
    AllowedGroupsColumnName: str


class AdditionalResultAttributeTypeDef(TypedDict):
    Key: str
    ValueType: Literal["TEXT_WITH_HIGHLIGHTS_VALUE"]
    Value: "AdditionalResultAttributeValueTypeDef"


class AdditionalResultAttributeValueTypeDef(TypedDict, total=False):
    TextWithHighlightsValue: "TextWithHighlightsTypeDef"


class AttributeFilterTypeDef(TypedDict, total=False):
    AndAllFilters: List[Dict[str, Any]]
    OrAllFilters: List[Dict[str, Any]]
    NotFilter: Dict[str, Any]
    EqualsTo: "DocumentAttributeTypeDef"
    ContainsAll: "DocumentAttributeTypeDef"
    ContainsAny: "DocumentAttributeTypeDef"
    GreaterThan: "DocumentAttributeTypeDef"
    GreaterThanOrEquals: "DocumentAttributeTypeDef"
    LessThan: "DocumentAttributeTypeDef"
    LessThanOrEquals: "DocumentAttributeTypeDef"


class BatchDeleteDocumentResponseFailedDocumentTypeDef(TypedDict, total=False):
    Id: str
    ErrorCode: ErrorCode
    ErrorMessage: str


class BatchDeleteDocumentResponseTypeDef(TypedDict, total=False):
    FailedDocuments: List["BatchDeleteDocumentResponseFailedDocumentTypeDef"]


class BatchPutDocumentResponseFailedDocumentTypeDef(TypedDict, total=False):
    Id: str
    ErrorCode: ErrorCode
    ErrorMessage: str


class BatchPutDocumentResponseTypeDef(TypedDict, total=False):
    FailedDocuments: List["BatchPutDocumentResponseFailedDocumentTypeDef"]


class CapacityUnitsConfigurationTypeDef(TypedDict):
    StorageCapacityUnits: int
    QueryCapacityUnits: int


class ClickFeedbackTypeDef(TypedDict):
    ResultId: str
    ClickTime: datetime


class _RequiredColumnConfigurationTypeDef(TypedDict):
    DocumentIdColumnName: str
    DocumentDataColumnName: str
    ChangeDetectingColumns: List[str]


class ColumnConfigurationTypeDef(_RequiredColumnConfigurationTypeDef, total=False):
    DocumentTitleColumnName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class ConfluenceAttachmentConfigurationTypeDef(TypedDict, total=False):
    CrawlAttachments: bool
    AttachmentFieldMappings: List["ConfluenceAttachmentToIndexFieldMappingTypeDef"]


class ConfluenceAttachmentToIndexFieldMappingTypeDef(TypedDict, total=False):
    DataSourceFieldName: ConfluenceAttachmentFieldName
    DateFieldFormat: str
    IndexFieldName: str


class ConfluenceBlogConfigurationTypeDef(TypedDict, total=False):
    BlogFieldMappings: List["ConfluenceBlogToIndexFieldMappingTypeDef"]


class ConfluenceBlogToIndexFieldMappingTypeDef(TypedDict, total=False):
    DataSourceFieldName: ConfluenceBlogFieldName
    DateFieldFormat: str
    IndexFieldName: str


class _RequiredConfluenceConfigurationTypeDef(TypedDict):
    ServerUrl: str
    SecretArn: str
    Version: ConfluenceVersion


class ConfluenceConfigurationTypeDef(_RequiredConfluenceConfigurationTypeDef, total=False):
    SpaceConfiguration: "ConfluenceSpaceConfigurationTypeDef"
    PageConfiguration: "ConfluencePageConfigurationTypeDef"
    BlogConfiguration: "ConfluenceBlogConfigurationTypeDef"
    AttachmentConfiguration: "ConfluenceAttachmentConfigurationTypeDef"
    VpcConfiguration: "DataSourceVpcConfigurationTypeDef"
    InclusionPatterns: List[str]
    ExclusionPatterns: List[str]


class ConfluencePageConfigurationTypeDef(TypedDict, total=False):
    PageFieldMappings: List["ConfluencePageToIndexFieldMappingTypeDef"]


class ConfluencePageToIndexFieldMappingTypeDef(TypedDict, total=False):
    DataSourceFieldName: ConfluencePageFieldName
    DateFieldFormat: str
    IndexFieldName: str


class ConfluenceSpaceConfigurationTypeDef(TypedDict, total=False):
    CrawlPersonalSpaces: bool
    CrawlArchivedSpaces: bool
    IncludeSpaces: List[str]
    ExcludeSpaces: List[str]
    SpaceFieldMappings: List["ConfluenceSpaceToIndexFieldMappingTypeDef"]


class ConfluenceSpaceToIndexFieldMappingTypeDef(TypedDict, total=False):
    DataSourceFieldName: ConfluenceSpaceFieldName
    DateFieldFormat: str
    IndexFieldName: str


class ConnectionConfigurationTypeDef(TypedDict):
    DatabaseHost: str
    DatabasePort: int
    DatabaseName: str
    TableName: str
    SecretArn: str


class CreateDataSourceResponseTypeDef(TypedDict):
    Id: str


class CreateFaqResponseTypeDef(TypedDict, total=False):
    Id: str


class CreateIndexResponseTypeDef(TypedDict, total=False):
    Id: str


class CreateThesaurusResponseTypeDef(TypedDict, total=False):
    Id: str


class DataSourceConfigurationTypeDef(TypedDict, total=False):
    S3Configuration: "S3DataSourceConfigurationTypeDef"
    SharePointConfiguration: "SharePointConfigurationTypeDef"
    DatabaseConfiguration: "DatabaseConfigurationTypeDef"
    SalesforceConfiguration: "SalesforceConfigurationTypeDef"
    OneDriveConfiguration: "OneDriveConfigurationTypeDef"
    ServiceNowConfiguration: "ServiceNowConfigurationTypeDef"
    ConfluenceConfiguration: "ConfluenceConfigurationTypeDef"
    GoogleDriveConfiguration: "GoogleDriveConfigurationTypeDef"


DataSourceSummaryTypeDef = TypedDict(
    "DataSourceSummaryTypeDef",
    {
        "Name": str,
        "Id": str,
        "Type": DataSourceType,
        "CreatedAt": datetime,
        "UpdatedAt": datetime,
        "Status": DataSourceStatus,
    },
    total=False,
)


class DataSourceSyncJobMetricTargetTypeDef(TypedDict):
    DataSourceId: str
    DataSourceSyncJobId: str


class DataSourceSyncJobMetricsTypeDef(TypedDict, total=False):
    DocumentsAdded: str
    DocumentsModified: str
    DocumentsDeleted: str
    DocumentsFailed: str
    DocumentsScanned: str


class DataSourceSyncJobTypeDef(TypedDict, total=False):
    ExecutionId: str
    StartTime: datetime
    EndTime: datetime
    Status: DataSourceSyncJobStatus
    ErrorMessage: str
    ErrorCode: ErrorCode
    DataSourceErrorCode: str
    Metrics: "DataSourceSyncJobMetricsTypeDef"


class _RequiredDataSourceToIndexFieldMappingTypeDef(TypedDict):
    DataSourceFieldName: str
    IndexFieldName: str


class DataSourceToIndexFieldMappingTypeDef(
    _RequiredDataSourceToIndexFieldMappingTypeDef, total=False
):
    DateFieldFormat: str


class DataSourceVpcConfigurationTypeDef(TypedDict):
    SubnetIds: List[str]
    SecurityGroupIds: List[str]


class _RequiredDatabaseConfigurationTypeDef(TypedDict):
    DatabaseEngineType: DatabaseEngineType
    ConnectionConfiguration: "ConnectionConfigurationTypeDef"
    ColumnConfiguration: "ColumnConfigurationTypeDef"


class DatabaseConfigurationTypeDef(_RequiredDatabaseConfigurationTypeDef, total=False):
    VpcConfiguration: "DataSourceVpcConfigurationTypeDef"
    AclConfiguration: "AclConfigurationTypeDef"
    SqlConfiguration: "SqlConfigurationTypeDef"


DescribeDataSourceResponseTypeDef = TypedDict(
    "DescribeDataSourceResponseTypeDef",
    {
        "Id": str,
        "IndexId": str,
        "Name": str,
        "Type": DataSourceType,
        "Configuration": "DataSourceConfigurationTypeDef",
        "CreatedAt": datetime,
        "UpdatedAt": datetime,
        "Description": str,
        "Status": DataSourceStatus,
        "Schedule": str,
        "RoleArn": str,
        "ErrorMessage": str,
    },
    total=False,
)


class DescribeFaqResponseTypeDef(TypedDict, total=False):
    Id: str
    IndexId: str
    Name: str
    Description: str
    CreatedAt: datetime
    UpdatedAt: datetime
    S3Path: "S3PathTypeDef"
    Status: FaqStatus
    RoleArn: str
    ErrorMessage: str
    FileFormat: FaqFileFormat


class DescribeIndexResponseTypeDef(TypedDict, total=False):
    Name: str
    Id: str
    Edition: IndexEdition
    RoleArn: str
    ServerSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef"
    Status: IndexStatus
    Description: str
    CreatedAt: datetime
    UpdatedAt: datetime
    DocumentMetadataConfigurations: List["DocumentMetadataConfigurationTypeDef"]
    IndexStatistics: "IndexStatisticsTypeDef"
    ErrorMessage: str
    CapacityUnits: "CapacityUnitsConfigurationTypeDef"
    UserTokenConfigurations: List["UserTokenConfigurationTypeDef"]
    UserContextPolicy: UserContextPolicy


class DescribeThesaurusResponseTypeDef(TypedDict, total=False):
    Id: str
    IndexId: str
    Name: str
    Description: str
    Status: ThesaurusStatus
    ErrorMessage: str
    CreatedAt: datetime
    UpdatedAt: datetime
    RoleArn: str
    SourceS3Path: "S3PathTypeDef"
    FileSizeBytes: int
    TermCount: int
    SynonymRuleCount: int


class DocumentAttributeTypeDef(TypedDict):
    Key: str
    Value: "DocumentAttributeValueTypeDef"


class DocumentAttributeValueCountPairTypeDef(TypedDict, total=False):
    DocumentAttributeValue: "DocumentAttributeValueTypeDef"
    Count: int


class DocumentAttributeValueTypeDef(TypedDict, total=False):
    StringValue: str
    StringListValue: List[str]
    LongValue: int
    DateValue: datetime


_RequiredDocumentMetadataConfigurationTypeDef = TypedDict(
    "_RequiredDocumentMetadataConfigurationTypeDef",
    {"Name": str, "Type": DocumentAttributeValueType},
)
_OptionalDocumentMetadataConfigurationTypeDef = TypedDict(
    "_OptionalDocumentMetadataConfigurationTypeDef",
    {"Relevance": "RelevanceTypeDef", "Search": "SearchTypeDef"},
    total=False,
)


class DocumentMetadataConfigurationTypeDef(
    _RequiredDocumentMetadataConfigurationTypeDef, _OptionalDocumentMetadataConfigurationTypeDef
):
    pass


class DocumentRelevanceConfigurationTypeDef(TypedDict):
    Name: str
    Relevance: "RelevanceTypeDef"


class _RequiredDocumentTypeDef(TypedDict):
    Id: str


class DocumentTypeDef(_RequiredDocumentTypeDef, total=False):
    Title: str
    Blob: Union[bytes, IO[bytes]]
    S3Path: "S3PathTypeDef"
    Attributes: List["DocumentAttributeTypeDef"]
    AccessControlList: List["PrincipalTypeDef"]
    ContentType: ContentType


class DocumentsMetadataConfigurationTypeDef(TypedDict, total=False):
    S3Prefix: str


class FacetResultTypeDef(TypedDict, total=False):
    DocumentAttributeKey: str
    DocumentAttributeValueType: DocumentAttributeValueType
    DocumentAttributeValueCountPairs: List["DocumentAttributeValueCountPairTypeDef"]


class FacetTypeDef(TypedDict, total=False):
    DocumentAttributeKey: str


class FaqStatisticsTypeDef(TypedDict):
    IndexedQuestionAnswersCount: int


class FaqSummaryTypeDef(TypedDict, total=False):
    Id: str
    Name: str
    Status: FaqStatus
    CreatedAt: datetime
    UpdatedAt: datetime
    FileFormat: FaqFileFormat


class _RequiredGoogleDriveConfigurationTypeDef(TypedDict):
    SecretArn: str


class GoogleDriveConfigurationTypeDef(_RequiredGoogleDriveConfigurationTypeDef, total=False):
    InclusionPatterns: List[str]
    ExclusionPatterns: List[str]
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]
    ExcludeMimeTypes: List[str]
    ExcludeUserAccounts: List[str]
    ExcludeSharedDrives: List[str]


_RequiredHighlightTypeDef = TypedDict(
    "_RequiredHighlightTypeDef", {"BeginOffset": int, "EndOffset": int}
)
_OptionalHighlightTypeDef = TypedDict(
    "_OptionalHighlightTypeDef", {"TopAnswer": bool, "Type": HighlightType}, total=False
)


class HighlightTypeDef(_RequiredHighlightTypeDef, _OptionalHighlightTypeDef):
    pass


class _RequiredIndexConfigurationSummaryTypeDef(TypedDict):
    CreatedAt: datetime
    UpdatedAt: datetime
    Status: IndexStatus


class IndexConfigurationSummaryTypeDef(_RequiredIndexConfigurationSummaryTypeDef, total=False):
    Name: str
    Id: str
    Edition: IndexEdition


class IndexStatisticsTypeDef(TypedDict):
    FaqStatistics: "FaqStatisticsTypeDef"
    TextDocumentStatistics: "TextDocumentStatisticsTypeDef"


class JsonTokenTypeConfigurationTypeDef(TypedDict):
    UserNameAttributeField: str
    GroupAttributeField: str


class _RequiredJwtTokenTypeConfigurationTypeDef(TypedDict):
    KeyLocation: KeyLocation


class JwtTokenTypeConfigurationTypeDef(_RequiredJwtTokenTypeConfigurationTypeDef, total=False):
    URL: str
    SecretManagerArn: str
    UserNameAttributeField: str
    GroupAttributeField: str
    Issuer: str
    ClaimRegex: str


class ListDataSourceSyncJobsResponseTypeDef(TypedDict, total=False):
    History: List["DataSourceSyncJobTypeDef"]
    NextToken: str


class ListDataSourcesResponseTypeDef(TypedDict, total=False):
    SummaryItems: List["DataSourceSummaryTypeDef"]
    NextToken: str


class ListFaqsResponseTypeDef(TypedDict, total=False):
    NextToken: str
    FaqSummaryItems: List["FaqSummaryTypeDef"]


class ListIndicesResponseTypeDef(TypedDict, total=False):
    IndexConfigurationSummaryItems: List["IndexConfigurationSummaryTypeDef"]
    NextToken: str


class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
    Tags: List["TagTypeDef"]


class ListThesauriResponseTypeDef(TypedDict, total=False):
    NextToken: str
    ThesaurusSummaryItems: List["ThesaurusSummaryTypeDef"]


class _RequiredOneDriveConfigurationTypeDef(TypedDict):
    TenantDomain: str
    SecretArn: str
    OneDriveUsers: "OneDriveUsersTypeDef"


class OneDriveConfigurationTypeDef(_RequiredOneDriveConfigurationTypeDef, total=False):
    InclusionPatterns: List[str]
    ExclusionPatterns: List[str]
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]
    DisableLocalGroups: bool


class OneDriveUsersTypeDef(TypedDict, total=False):
    OneDriveUserList: List[str]
    OneDriveUserS3Path: "S3PathTypeDef"


PrincipalTypeDef = TypedDict(
    "PrincipalTypeDef", {"Name": str, "Type": PrincipalType, "Access": ReadAccessType}
)

QueryResultItemTypeDef = TypedDict(
    "QueryResultItemTypeDef",
    {
        "Id": str,
        "Type": QueryResultType,
        "AdditionalAttributes": List["AdditionalResultAttributeTypeDef"],
        "DocumentId": str,
        "DocumentTitle": "TextWithHighlightsTypeDef",
        "DocumentExcerpt": "TextWithHighlightsTypeDef",
        "DocumentURI": str,
        "DocumentAttributes": List["DocumentAttributeTypeDef"],
        "ScoreAttributes": "ScoreAttributesTypeDef",
        "FeedbackToken": str,
    },
    total=False,
)


class QueryResultTypeDef(TypedDict, total=False):
    QueryId: str
    ResultItems: List["QueryResultItemTypeDef"]
    FacetResults: List["FacetResultTypeDef"]
    TotalNumberOfResults: int


class RelevanceFeedbackTypeDef(TypedDict):
    ResultId: str
    RelevanceValue: RelevanceType


class RelevanceTypeDef(TypedDict, total=False):
    Freshness: bool
    Importance: int
    Duration: str
    RankOrder: Order
    ValueImportanceMap: Dict[str, int]


class _RequiredS3DataSourceConfigurationTypeDef(TypedDict):
    BucketName: str


class S3DataSourceConfigurationTypeDef(_RequiredS3DataSourceConfigurationTypeDef, total=False):
    InclusionPrefixes: List[str]
    InclusionPatterns: List[str]
    ExclusionPatterns: List[str]
    DocumentsMetadataConfiguration: "DocumentsMetadataConfigurationTypeDef"
    AccessControlListConfiguration: "AccessControlListConfigurationTypeDef"


class S3PathTypeDef(TypedDict):
    Bucket: str
    Key: str


class _RequiredSalesforceChatterFeedConfigurationTypeDef(TypedDict):
    DocumentDataFieldName: str


class SalesforceChatterFeedConfigurationTypeDef(
    _RequiredSalesforceChatterFeedConfigurationTypeDef, total=False
):
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]
    IncludeFilterTypes: List[SalesforceChatterFeedIncludeFilterType]


class _RequiredSalesforceConfigurationTypeDef(TypedDict):
    ServerUrl: str
    SecretArn: str


class SalesforceConfigurationTypeDef(_RequiredSalesforceConfigurationTypeDef, total=False):
    StandardObjectConfigurations: List["SalesforceStandardObjectConfigurationTypeDef"]
    KnowledgeArticleConfiguration: "SalesforceKnowledgeArticleConfigurationTypeDef"
    ChatterFeedConfiguration: "SalesforceChatterFeedConfigurationTypeDef"
    CrawlAttachments: bool
    StandardObjectAttachmentConfiguration: "SalesforceStandardObjectAttachmentConfigurationTypeDef"
    IncludeAttachmentFilePatterns: List[str]
    ExcludeAttachmentFilePatterns: List[str]


class _RequiredSalesforceCustomKnowledgeArticleTypeConfigurationTypeDef(TypedDict):
    Name: str
    DocumentDataFieldName: str


class SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef(
    _RequiredSalesforceCustomKnowledgeArticleTypeConfigurationTypeDef, total=False
):
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class _RequiredSalesforceKnowledgeArticleConfigurationTypeDef(TypedDict):
    IncludedStates: List[SalesforceKnowledgeArticleState]


class SalesforceKnowledgeArticleConfigurationTypeDef(
    _RequiredSalesforceKnowledgeArticleConfigurationTypeDef, total=False
):
    StandardKnowledgeArticleTypeConfiguration: "SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef"
    CustomKnowledgeArticleTypeConfigurations: List[
        "SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef"
    ]


class _RequiredSalesforceStandardKnowledgeArticleTypeConfigurationTypeDef(TypedDict):
    DocumentDataFieldName: str


class SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef(
    _RequiredSalesforceStandardKnowledgeArticleTypeConfigurationTypeDef, total=False
):
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class SalesforceStandardObjectAttachmentConfigurationTypeDef(TypedDict, total=False):
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class _RequiredSalesforceStandardObjectConfigurationTypeDef(TypedDict):
    Name: SalesforceStandardObjectName
    DocumentDataFieldName: str


class SalesforceStandardObjectConfigurationTypeDef(
    _RequiredSalesforceStandardObjectConfigurationTypeDef, total=False
):
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class ScoreAttributesTypeDef(TypedDict, total=False):
    ScoreConfidence: ScoreConfidence


class SearchTypeDef(TypedDict, total=False):
    Facetable: bool
    Searchable: bool
    Displayable: bool
    Sortable: bool


class ServerSideEncryptionConfigurationTypeDef(TypedDict, total=False):
    KmsKeyId: str


class _RequiredServiceNowConfigurationTypeDef(TypedDict):
    HostUrl: str
    SecretArn: str
    ServiceNowBuildVersion: ServiceNowBuildVersionType


class ServiceNowConfigurationTypeDef(_RequiredServiceNowConfigurationTypeDef, total=False):
    KnowledgeArticleConfiguration: "ServiceNowKnowledgeArticleConfigurationTypeDef"
    ServiceCatalogConfiguration: "ServiceNowServiceCatalogConfigurationTypeDef"
    AuthenticationType: ServiceNowAuthenticationType


class _RequiredServiceNowKnowledgeArticleConfigurationTypeDef(TypedDict):
    DocumentDataFieldName: str


class ServiceNowKnowledgeArticleConfigurationTypeDef(
    _RequiredServiceNowKnowledgeArticleConfigurationTypeDef, total=False
):
    CrawlAttachments: bool
    IncludeAttachmentFilePatterns: List[str]
    ExcludeAttachmentFilePatterns: List[str]
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]
    FilterQuery: str


class _RequiredServiceNowServiceCatalogConfigurationTypeDef(TypedDict):
    DocumentDataFieldName: str


class ServiceNowServiceCatalogConfigurationTypeDef(
    _RequiredServiceNowServiceCatalogConfigurationTypeDef, total=False
):
    CrawlAttachments: bool
    IncludeAttachmentFilePatterns: List[str]
    ExcludeAttachmentFilePatterns: List[str]
    DocumentTitleFieldName: str
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]


class _RequiredSharePointConfigurationTypeDef(TypedDict):
    SharePointVersion: Literal["SHAREPOINT_ONLINE"]
    Urls: List[str]
    SecretArn: str


class SharePointConfigurationTypeDef(_RequiredSharePointConfigurationTypeDef, total=False):
    CrawlAttachments: bool
    UseChangeLog: bool
    InclusionPatterns: List[str]
    ExclusionPatterns: List[str]
    VpcConfiguration: "DataSourceVpcConfigurationTypeDef"
    FieldMappings: List["DataSourceToIndexFieldMappingTypeDef"]
    DocumentTitleFieldName: str
    DisableLocalGroups: bool


class SortingConfigurationTypeDef(TypedDict):
    DocumentAttributeKey: str
    SortOrder: SortOrder


class SqlConfigurationTypeDef(TypedDict, total=False):
    QueryIdentifiersEnclosingOption: QueryIdentifiersEnclosingOption


class StartDataSourceSyncJobResponseTypeDef(TypedDict, total=False):
    ExecutionId: str


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class TextDocumentStatisticsTypeDef(TypedDict):
    IndexedTextDocumentsCount: int
    IndexedTextBytes: int


TextWithHighlightsTypeDef = TypedDict(
    "TextWithHighlightsTypeDef", {"Text": str, "Highlights": List["HighlightTypeDef"]}, total=False
)


class ThesaurusSummaryTypeDef(TypedDict, total=False):
    Id: str
    Name: str
    Status: ThesaurusStatus
    CreatedAt: datetime
    UpdatedAt: datetime


class TimeRangeTypeDef(TypedDict, total=False):
    StartTime: datetime
    EndTime: datetime


class UserContextTypeDef(TypedDict, total=False):
    Token: str


class UserTokenConfigurationTypeDef(TypedDict, total=False):
    JwtTokenTypeConfiguration: "JwtTokenTypeConfigurationTypeDef"
    JsonTokenTypeConfiguration: "JsonTokenTypeConfigurationTypeDef"



"""
Type annotations for kendra service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/literals.html)

Usage::

    ```python
    from mypy_boto3_kendra.literals import AdditionalResultAttributeValueType

    data: AdditionalResultAttributeValueType = "TEXT_WITH_HIGHLIGHTS_VALUE"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "AdditionalResultAttributeValueType",
    "ConfluenceAttachmentFieldName",
    "ConfluenceBlogFieldName",
    "ConfluencePageFieldName",
    "ConfluenceSpaceFieldName",
    "ConfluenceVersion",
    "ContentType",
    "DataSourceStatus",
    "DataSourceSyncJobStatus",
    "DataSourceType",
    "DatabaseEngineType",
    "DocumentAttributeValueType",
    "ErrorCode",
    "FaqFileFormat",
    "FaqStatus",
    "HighlightType",
    "IndexEdition",
    "IndexStatus",
    "KeyLocation",
    "Order",
    "PrincipalType",
    "QueryIdentifiersEnclosingOption",
    "QueryResultType",
    "ReadAccessType",
    "RelevanceType",
    "SalesforceChatterFeedIncludeFilterType",
    "SalesforceKnowledgeArticleState",
    "SalesforceStandardObjectName",
    "ScoreConfidence",
    "ServiceNowAuthenticationType",
    "ServiceNowBuildVersionType",
    "SharePointVersion",
    "SortOrder",
    "ThesaurusStatus",
    "UserContextPolicy",
)


AdditionalResultAttributeValueType = Literal["TEXT_WITH_HIGHLIGHTS_VALUE"]
ConfluenceAttachmentFieldName = Literal[
    "AUTHOR",
    "CONTENT_TYPE",
    "CREATED_DATE",
    "DISPLAY_URL",
    "FILE_SIZE",
    "ITEM_TYPE",
    "PARENT_ID",
    "SPACE_KEY",
    "SPACE_NAME",
    "URL",
    "VERSION",
]
ConfluenceBlogFieldName = Literal[
    "AUTHOR",
    "DISPLAY_URL",
    "ITEM_TYPE",
    "LABELS",
    "PUBLISH_DATE",
    "SPACE_KEY",
    "SPACE_NAME",
    "URL",
    "VERSION",
]
ConfluencePageFieldName = Literal[
    "AUTHOR",
    "CONTENT_STATUS",
    "CREATED_DATE",
    "DISPLAY_URL",
    "ITEM_TYPE",
    "LABELS",
    "MODIFIED_DATE",
    "PARENT_ID",
    "SPACE_KEY",
    "SPACE_NAME",
    "URL",
    "VERSION",
]
ConfluenceSpaceFieldName = Literal["DISPLAY_URL", "ITEM_TYPE", "SPACE_KEY", "URL"]
ConfluenceVersion = Literal["CLOUD", "SERVER"]
ContentType = Literal["HTML", "MS_WORD", "PDF", "PLAIN_TEXT", "PPT"]
DataSourceStatus = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
DataSourceSyncJobStatus = Literal[
    "ABORTED", "FAILED", "INCOMPLETE", "STOPPING", "SUCCEEDED", "SYNCING", "SYNCING_INDEXING"
]
DataSourceType = Literal[
    "CONFLUENCE",
    "CUSTOM",
    "DATABASE",
    "GOOGLEDRIVE",
    "ONEDRIVE",
    "S3",
    "SALESFORCE",
    "SERVICENOW",
    "SHAREPOINT",
]
DatabaseEngineType = Literal[
    "RDS_AURORA_MYSQL", "RDS_AURORA_POSTGRESQL", "RDS_MYSQL", "RDS_POSTGRESQL"
]
DocumentAttributeValueType = Literal[
    "DATE_VALUE", "LONG_VALUE", "STRING_LIST_VALUE", "STRING_VALUE"
]
ErrorCode = Literal["InternalError", "InvalidRequest"]
FaqFileFormat = Literal["CSV", "CSV_WITH_HEADER", "JSON"]
FaqStatus = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
HighlightType = Literal["STANDARD", "THESAURUS_SYNONYM"]
IndexEdition = Literal["DEVELOPER_EDITION", "ENTERPRISE_EDITION"]
IndexStatus = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "SYSTEM_UPDATING", "UPDATING"]
KeyLocation = Literal["SECRET_MANAGER", "URL"]
Order = Literal["ASCENDING", "DESCENDING"]
PrincipalType = Literal["GROUP", "USER"]
QueryIdentifiersEnclosingOption = Literal["DOUBLE_QUOTES", "NONE"]
QueryResultType = Literal["ANSWER", "DOCUMENT", "QUESTION_ANSWER"]
ReadAccessType = Literal["ALLOW", "DENY"]
RelevanceType = Literal["NOT_RELEVANT", "RELEVANT"]
SalesforceChatterFeedIncludeFilterType = Literal["ACTIVE_USER", "STANDARD_USER"]
SalesforceKnowledgeArticleState = Literal["ARCHIVED", "DRAFT", "PUBLISHED"]
SalesforceStandardObjectName = Literal[
    "ACCOUNT",
    "CAMPAIGN",
    "CASE",
    "CONTACT",
    "CONTRACT",
    "DOCUMENT",
    "GROUP",
    "IDEA",
    "LEAD",
    "OPPORTUNITY",
    "PARTNER",
    "PRICEBOOK",
    "PRODUCT",
    "PROFILE",
    "SOLUTION",
    "TASK",
    "USER",
]
ScoreConfidence = Literal["HIGH", "LOW", "MEDIUM", "VERY_HIGH"]
ServiceNowAuthenticationType = Literal["HTTP_BASIC", "OAUTH2"]
ServiceNowBuildVersionType = Literal["LONDON", "OTHERS"]
SharePointVersion = Literal["SHAREPOINT_ONLINE"]
SortOrder = Literal["ASC", "DESC"]
ThesaurusStatus = Literal[
    "ACTIVE", "ACTIVE_BUT_UPDATE_FAILED", "CREATING", "DELETING", "FAILED", "UPDATING"
]
UserContextPolicy = Literal["ATTRIBUTE_FILTER", "USER_TOKEN"]



"""
Type annotations for kendra service client.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html)

Usage::

    ```python
    import boto3
    from mypy_boto3_kendra import KendraClient

    client: KendraClient = boto3.client("kendra")
    ```
"""
from typing import Any, Dict, List, Type

from botocore.client import ClientMeta

from mypy_boto3_kendra.literals import (
    DataSourceSyncJobStatus,
    DataSourceType,
    FaqFileFormat,
    IndexEdition,
    QueryResultType,
    UserContextPolicy,
)
from mypy_boto3_kendra.type_defs import (
    AttributeFilterTypeDef,
    BatchDeleteDocumentResponseTypeDef,
    BatchPutDocumentResponseTypeDef,
    CapacityUnitsConfigurationTypeDef,
    ClickFeedbackTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFaqResponseTypeDef,
    CreateIndexResponseTypeDef,
    CreateThesaurusResponseTypeDef,
    DataSourceConfigurationTypeDef,
    DataSourceSyncJobMetricTargetTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeFaqResponseTypeDef,
    DescribeIndexResponseTypeDef,
    DescribeThesaurusResponseTypeDef,
    DocumentMetadataConfigurationTypeDef,
    DocumentRelevanceConfigurationTypeDef,
    DocumentTypeDef,
    FacetTypeDef,
    ListDataSourcesResponseTypeDef,
    ListDataSourceSyncJobsResponseTypeDef,
    ListFaqsResponseTypeDef,
    ListIndicesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThesauriResponseTypeDef,
    QueryResultTypeDef,
    RelevanceFeedbackTypeDef,
    S3PathTypeDef,
    ServerSideEncryptionConfigurationTypeDef,
    SortingConfigurationTypeDef,
    StartDataSourceSyncJobResponseTypeDef,
    TagTypeDef,
    TimeRangeTypeDef,
    UserContextTypeDef,
    UserTokenConfigurationTypeDef,
)

__all__ = ("KendraClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceAlreadyExistException: Type[BotocoreClientError]
    ResourceInUseException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ResourceUnavailableException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class KendraClient:
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client)
    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html)
    """

    meta: ClientMeta
    exceptions: Exceptions

    def batch_delete_document(
        self,
        IndexId: str,
        DocumentIdList: List[str],
        DataSourceSyncJobMetricTarget: DataSourceSyncJobMetricTargetTypeDef = None,
    ) -> BatchDeleteDocumentResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.batch_delete_document)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch-delete-document)
        """

    def batch_put_document(
        self, IndexId: str, Documents: List[DocumentTypeDef], RoleArn: str = None
    ) -> BatchPutDocumentResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.batch_put_document)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch-put-document)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.can_paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#can-paginate)
        """

    def create_data_source(
        self,
        Name: str,
        IndexId: str,
        Type: DataSourceType,
        Configuration: "DataSourceConfigurationTypeDef" = None,
        Description: str = None,
        Schedule: str = None,
        RoleArn: str = None,
        Tags: List["TagTypeDef"] = None,
        ClientToken: str = None,
    ) -> CreateDataSourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.create_data_source)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create-data-source)
        """

    def create_faq(
        self,
        IndexId: str,
        Name: str,
        S3Path: "S3PathTypeDef",
        RoleArn: str,
        Description: str = None,
        Tags: List["TagTypeDef"] = None,
        FileFormat: FaqFileFormat = None,
        ClientToken: str = None,
    ) -> CreateFaqResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.create_faq)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create-faq)
        """

    def create_index(
        self,
        Name: str,
        RoleArn: str,
        Edition: IndexEdition = None,
        ServerSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef" = None,
        Description: str = None,
        ClientToken: str = None,
        Tags: List["TagTypeDef"] = None,
        UserTokenConfigurations: List["UserTokenConfigurationTypeDef"] = None,
        UserContextPolicy: UserContextPolicy = None,
    ) -> CreateIndexResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.create_index)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create-index)
        """

    def create_thesaurus(
        self,
        IndexId: str,
        Name: str,
        RoleArn: str,
        SourceS3Path: "S3PathTypeDef",
        Description: str = None,
        Tags: List["TagTypeDef"] = None,
        ClientToken: str = None,
    ) -> CreateThesaurusResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.create_thesaurus)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create-thesaurus)
        """

    def delete_data_source(self, Id: str, IndexId: str) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.delete_data_source)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete-data-source)
        """

    def delete_faq(self, Id: str, IndexId: str) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.delete_faq)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete-faq)
        """

    def delete_index(self, Id: str) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.delete_index)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete-index)
        """

    def delete_thesaurus(self, Id: str, IndexId: str) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.delete_thesaurus)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete-thesaurus)
        """

    def describe_data_source(self, Id: str, IndexId: str) -> DescribeDataSourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.describe_data_source)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe-data-source)
        """

    def describe_faq(self, Id: str, IndexId: str) -> DescribeFaqResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.describe_faq)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe-faq)
        """

    def describe_index(self, Id: str) -> DescribeIndexResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.describe_index)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe-index)
        """

    def describe_thesaurus(self, Id: str, IndexId: str) -> DescribeThesaurusResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.describe_thesaurus)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe-thesaurus)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#generate-presigned-url)
        """

    def list_data_source_sync_jobs(
        self,
        Id: str,
        IndexId: str,
        NextToken: str = None,
        MaxResults: int = None,
        StartTimeFilter: TimeRangeTypeDef = None,
        StatusFilter: DataSourceSyncJobStatus = None,
    ) -> ListDataSourceSyncJobsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_data_source_sync_jobs)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-data-source-sync-jobs)
        """

    def list_data_sources(
        self, IndexId: str, NextToken: str = None, MaxResults: int = None
    ) -> ListDataSourcesResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_data_sources)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-data-sources)
        """

    def list_faqs(
        self, IndexId: str, NextToken: str = None, MaxResults: int = None
    ) -> ListFaqsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_faqs)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-faqs)
        """

    def list_indices(
        self, NextToken: str = None, MaxResults: int = None
    ) -> ListIndicesResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_indices)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-indices)
        """

    def list_tags_for_resource(self, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_tags_for_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-tags-for-resource)
        """

    def list_thesauri(
        self, IndexId: str, NextToken: str = None, MaxResults: int = None
    ) -> ListThesauriResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.list_thesauri)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list-thesauri)
        """

    def query(
        self,
        IndexId: str,
        QueryText: str,
        AttributeFilter: "AttributeFilterTypeDef" = None,
        Facets: List[FacetTypeDef] = None,
        RequestedDocumentAttributes: List[str] = None,
        QueryResultTypeFilter: QueryResultType = None,
        DocumentRelevanceOverrideConfigurations: List[DocumentRelevanceConfigurationTypeDef] = None,
        PageNumber: int = None,
        PageSize: int = None,
        SortingConfiguration: SortingConfigurationTypeDef = None,
        UserContext: UserContextTypeDef = None,
        VisitorId: str = None,
    ) -> QueryResultTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.query)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#query)
        """

    def start_data_source_sync_job(
        self, Id: str, IndexId: str
    ) -> StartDataSourceSyncJobResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.start_data_source_sync_job)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#start-data-source-sync-job)
        """

    def stop_data_source_sync_job(self, Id: str, IndexId: str) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.stop_data_source_sync_job)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#stop-data-source-sync-job)
        """

    def submit_feedback(
        self,
        IndexId: str,
        QueryId: str,
        ClickFeedbackItems: List[ClickFeedbackTypeDef] = None,
        RelevanceFeedbackItems: List[RelevanceFeedbackTypeDef] = None,
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.submit_feedback)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#submit-feedback)
        """

    def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.tag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#tag-resource)
        """

    def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.untag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#untag-resource)
        """

    def update_data_source(
        self,
        Id: str,
        IndexId: str,
        Name: str = None,
        Configuration: "DataSourceConfigurationTypeDef" = None,
        Description: str = None,
        Schedule: str = None,
        RoleArn: str = None,
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.update_data_source)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update-data-source)
        """

    def update_index(
        self,
        Id: str,
        Name: str = None,
        RoleArn: str = None,
        Description: str = None,
        DocumentMetadataConfigurationUpdates: List["DocumentMetadataConfigurationTypeDef"] = None,
        CapacityUnits: "CapacityUnitsConfigurationTypeDef" = None,
        UserTokenConfigurations: List["UserTokenConfigurationTypeDef"] = None,
        UserContextPolicy: UserContextPolicy = None,
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.update_index)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update-index)
        """

    def update_thesaurus(
        self,
        Id: str,
        IndexId: str,
        Name: str = None,
        Description: str = None,
        RoleArn: str = None,
        SourceS3Path: "S3PathTypeDef" = None,
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/kendra.html#Kendra.Client.update_thesaurus)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update-thesaurus)
        """
